#ifndef _HW3_H_ 
#define _HW3_H_

#define MAX_NAME_SIZE 32
#define MAX_PREFERENCES 4  /* maximum number of prefered dance partners */

#define MAX_DANCERS 64   /* maximum number of dancers in the tournament */
#define MAX_PAIRS (MAX_DANCERS/2)

typedef struct dancer {
	char name[MAX_NAME_SIZE];
	int id;
	int preference_ids[MAX_PREFERENCES];
	double dancing_ability;
} dancer_t;

typedef struct dancing_pair {
	dancer_t *dancer1; 
	dancer_t *dancer2;
} dancing_pair_t;

/* lib_gen_dancers
 *
 * Generates 'num_dancers' dancers in a pseudorandom number and stores them in the table.
 *
 * dancers: the table where the dancers are stored, size MAX_DANCERS
 * num_dancers: the number of dancers stored in the table
 * seed: initializes the pseudorandom number generator.
 *
 * Notes: 
 * num_dancers must be a power of 2. If not, the program terminates.
 *
 * If the seed is zero, then the generator is initialized using the current time, 
 * otherwise it is initialized using the seed's value. 
 
 * Furthermore:
 * If seed%4 is 1, the generated dancers have no mutual relations, in other
 * words, if dancer i likes dancer j, then dancer j will not like dancer i.
 * 
 * If seed%4 is 2, there are always mutual pairings between dancers who like
 * each other, in other words every dancer can be matched with a dancer he/she likes.
 * 
 * If seed%4 is 3, the generated dancers are a mix of the cases 1 and 2.
 * 
 * Otherwise, the relationships are generated randomly.
 */
void lib_gen_dancers(dancer_t dancers[], int num_dancers, unsigned int seed);

/* lib_get_random
 * 
 * Returns a pseudorandom double number in the range [min_value, max_value)
 */
double lib_get_random(double min_value, double max_value);

#endif
